//
//  RedactedAppDelegate.m
//  Redacted
//
//  Created by Craig Hockenberry on 7/2/08.
//  Copyright The Iconfactory 2008. All rights reserved.
//

#import "RedactedAppDelegate.h"
#import "RootViewController.h"

@implementation RedactedAppDelegate


@synthesize window;
@synthesize rootViewController;


- (void)applicationDidFinishLaunching:(UIApplication *)application
{
	[window addSubview:[rootViewController view]];
	[window makeKeyAndVisible];
}


- (void)dealloc
{
	[rootViewController release];
	[window release];
	[super dealloc];
}

- (void)processMessage:(NSString *)message
{
	// do something with the message

	NSLog(@"RedactedAppDelegate: processMessage = %@", message);
}

// The following application delegate method will be called for each URL scheme that is configured
// in your Info.plist.
//
// The following is used by this application so that it will respond to redacted://
//
//	<key>CFBundleURLTypes</key>
//	<array>
//		<dict>
//			<key>CFBundleURLName</key>
//			<string>com.iconfactory.${PRODUCT_NAME:identifier}</string>
//			<key>CFBundleURLSchemes</key>
//			<array>
//				<string>redacted</string>
//			</array>
//		</dict>
//	</array>
//
// More information about registering URL schemes can be found in the iPhone OS Programming Guide under
// Application Configuration > Registering Custom URL Schemes.

- (BOOL)application:(UIApplication *)application handleOpenURL:(NSURL *)url
{
	NSLog(@"RedactedAppDelegate: application:handleOpenURL: url = %@", url);

	// NOTE: This is the same URL parser that is in Twitterrific. It shows how you can extract
	// information from the URL.
	
	// The parser assumes that the URL is formatted as follows:
	//
	//   redacted:///post?message=URL%20encoded%20text%20with%20%3D%20and%20%26%20escaped
	//
	// See the postToTwitter: method for an example of how to do the URL encoding.
		
	BOOL handledURL = NO;
	
	if ([@"/post" isEqualToString:[url path]])
	{
		NSArray *queryComponents = [[url query] componentsSeparatedByString:@"&"];
		NSString *queryComponent;
		for (queryComponent in queryComponents)
		{
			NSArray	*query = [queryComponent componentsSeparatedByString:@"="];
			if ([query count] == 2)
			{
				NSString *queryKey = [query objectAtIndex:0];
				NSString *queryValue = [query objectAtIndex:1];
				
				if ([@"message" isEqualToString:queryKey])
				{
					NSString *decodedMessage = (NSString *)CFURLCreateStringByReplacingPercentEscapes(kCFAllocatorDefault, (CFStringRef)queryValue, CFSTR(""));
					// Twitterrific will open the post panel and set the message to decodedMessage at this point
					[self processMessage:decodedMessage];
					[decodedMessage release];
					
					handledURL = YES;
				}
			}
		}
	}
	
	return handledURL;
}


@end
